==> haskell-bin-0.1.3-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bin
version:              0.1.3
visibility:           public
id:                   bin-0.1.3-KrMQKLLJuk2BsjniLsQMhR
key:                  bin-0.1.3-KrMQKLLJuk2BsjniLsQMhR
license:              GPL-2.0-or-later
copyright:            (c) 2019-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Bin: binary natural numbers.
description:
    This package provides /binary natural numbers/ ("Data.Bin");
    also utilities to work on the type level with @DataKinds@ ("Data.Type.Bin").

    @
    data Bin
    \    = BZ       -- ^ zero
    \    | BP BinP  -- ^ non-zero

    data BinP
    \    = BE       -- ^ one
    \    | B0 BinP  -- ^ double
    \    | B1 BinP  -- ^ double plus 1
    @

    There are /ordinals/ in "Data.Bin.Pos" module, as well as
    fixed width integers in "Data.Wrd".

    Another implementation is at <https://hackage.haskell.org/package/nat>,
    this differs in naming, and provides promoted variant.

category:             Data, Dependent Types, Singletons, Math
abi:                  9a27bae8d816845115ffef08cc08a294
exposed:              True
exposed-modules:
    Data.Bin Data.Bin.Pos Data.BinP Data.BinP.PosP Data.Type.Bin
    Data.Type.BinP Data.Wrd

hidden-modules:       TrustworthyCompat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/bin-0.1.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/bin-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bin
hs-libraries:         HSbin-0.1.3-KrMQKLLJuk2BsjniLsQMhR
depends:
    QuickCheck-2.14.3-ETIaN96hws5IxTx9oCxxHN base-4.16.4.0
    boring-0.2.1-4ay7NZ1mR0V485tuSNtr0u dec-0.0.5-mxthkKDKJzCevwszd0Rua
    deepseq-1.4.6.1 fin-0.3-5453wpSIITsASvhH9wxABo
    hashable-1.4.4.0-JynHLbpSPE72B4j6uWctY4
    some-1.0.5-L5glA67mR8RJufLDsA2lRz

haddock-interfaces:   /usr/share/doc/haskell-bin/html/bin.haddock
haddock-html:         /usr/share/doc/haskell-bin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bin-0.1.3-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bin
version:              0.1.3
visibility:           public
id:                   bin-0.1.3-5pJNYZJT5DK7G1h0BMdCV8
key:                  bin-0.1.3-5pJNYZJT5DK7G1h0BMdCV8
license:              GPL-2.0-or-later
copyright:            (c) 2019-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Bin: binary natural numbers.
description:
    This package provides /binary natural numbers/ ("Data.Bin");
    also utilities to work on the type level with @DataKinds@ ("Data.Type.Bin").

    @
    data Bin
    \    = BZ       -- ^ zero
    \    | BP BinP  -- ^ non-zero

    data BinP
    \    = BE       -- ^ one
    \    | B0 BinP  -- ^ double
    \    | B1 BinP  -- ^ double plus 1
    @

    There are /ordinals/ in "Data.Bin.Pos" module, as well as
    fixed width integers in "Data.Wrd".

    Another implementation is at <https://hackage.haskell.org/package/nat>,
    this differs in naming, and provides promoted variant.

category:             Data, Dependent Types, Singletons, Math
abi:                  ef02b75992be4f2bdc0a75781ad2048e
exposed:              True
exposed-modules:
    Data.Bin Data.Bin.Pos Data.BinP Data.BinP.PosP Data.Type.Bin
    Data.Type.BinP Data.Wrd

hidden-modules:       TrustworthyCompat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/bin-0.1.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/bin-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bin
hs-libraries:         HSbin-0.1.3-5pJNYZJT5DK7G1h0BMdCV8
depends:
    QuickCheck-2.14.3-7UtqTMZe3jxBonzxyjYW4P base-4.16.4.0
    boring-0.2.1-4ay7NZ1mR0V485tuSNtr0u dec-0.0.5-mxthkKDKJzCevwszd0Rua
    deepseq-1.4.6.1 fin-0.3-LXnnHHMVBMP1wLu59ZiGOQ
    hashable-1.4.4.0-4PDYVYgOfaOHbKjFqbnqvX
    some-1.0.5-L5glA67mR8RJufLDsA2lRz

haddock-interfaces:   /usr/share/doc/haskell-bin/html/bin.haddock
haddock-html:         /usr/share/doc/haskell-bin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
